pub struct TransportConfig {
pub transport_type: TransportType,
pub connect_timeout: Duration,
pub read_timeout: Option<Duration>,
pub write_timeout: Option<Duration>,
pub keep_alive: Option<Duration>,
pub max_connections: Option<usize>,
pub compression: bool,
pub compression_algorithm: Option<String>,
pub limits: LimitsConfig,
pub timeouts: TimeoutConfig,
pub tls: TlsConfig,
pub custom: HashMap<String, Value>,
}Expand description
Configuration for a transport instance.
Fields
transport_type: TransportTypeThe type of the transport.
connect_timeout: DurationThe maximum time to wait for a connection to be established.
read_timeout: Option<Duration>The maximum time to wait for a read operation to complete.
write_timeout: Option<Duration>The maximum time to wait for a write operation to complete.
keep_alive: Option<Duration>The interval for sending keep-alive messages to maintain the connection.
max_connections: Option<usize>The maximum number of concurrent connections allowed.
compression: boolWhether to enable message compression.
compression_algorithm: Option<String>The preferred compression algorithm to use.
limits: LimitsConfigSize limits for requests and responses.
timeouts: TimeoutConfigTimeout configuration for operations.
tls: TlsConfigTLS/HTTPS configuration.
custom: HashMap<String, Value>A map for any other custom configuration.